@@ -1,11 +1,10 @@
 
 import  click
-from takeaway.core.utils.version import  get_version
 import math
 import random
 import time
 from takeaway.controllers.commands import  Operation
-
+from takeaway.core.utils.version import  VERSION
 @click.group()
 def cli():
     """Takeaway group Cli"""
@@ -20,9 +19,8 @@ def clear():
 
 @cli.command(help='😄 simple boilerplate ready for development')
 @click.option('--app','-a',type=click.Choice(['fastapi', 'flask','django'], case_sensitive=True), prompt='Choose one of the application',show_default=True,confirmation_prompt="confirm",default='fastapi',required=True, help='the app name')
-@click.option('--version',"-v",metavar='  version of program', is_flag=False, callback=get_version,
-              expose_value=False, is_eager=True)
 @click.option('--name',"-n",metavar='     the name of yor app',prompt='Name for your app',show_default=True,default='myproject',required=True, help='the app name')
+@click.version_option(VERSION)
 def cli(app,name,count=4000):
     click.echo(click.style('Starting app %s at directory %s!' % (app,name), fg='green'))
     click.progressbar(iterable="8", length=None, label=None, show_eta=True, show_percent=None, show_pos=False, item_show_func=None, fill_char='#', empty_char='-', bar_template='%(label)s [%(bar)s] %(info)s', info_sep=' ', width=36, file=None, color=None)
