@@ -1,13 +1,17 @@
 req ='''
 alembic==1.4.2
 astroid==2.3.3
+bandit==1.6.2
 click==7.1.1
 colorama==0.4.3
 Flask==1.1.2
 Flask-Env==2.0.0
+Flask-JWT-Extended==3.24.1
 flask-marshmallow==0.11.0
 Flask-Migrate==2.5.3
 Flask-SQLAlchemy==2.4.1
+gitdb==4.0.5
+GitPython==3.1.3
 isort==4.3.21
 itsdangerous==1.1.0
 Jinja2==2.11.1
@@ -18,14 +22,21 @@ marshmallow==3.5.1
 marshmallow-sqlalchemy==0.22.3
 mccabe==0.6.1
 passlib==1.7.2
+pbr==5.4.5
+pkg-resources==0.0.0
 psycopg2==2.8.5
+PyJWT==1.7.1
 pylint==2.4.4
 python-dateutil==2.8.1
 python-editor==1.0.4
+PyYAML==5.3.1
 six==1.14.0
+smmap==3.0.4
 SQLAlchemy==1.3.16
+stevedore==2.0.0
 typed-ast==1.4.1
 Werkzeug==1.0.1
 wrapt==1.11.2
 
+
 '''
\ No newline at end of file
